from .only_common import *

__copyright__    = 'Copyright (C) 2021 Takao Morita'
__version__      = '2.0.0'
__license__      = 'MIT'
__author__       = 'Takao Morita'
__author_email__ = 'tmolita077@gmail.com'
__url__          = 'https://github.com/taotaotao3/only_common'

# __all__ = ['公開モジュール', ...]